@@ -1,7 +1,8 @@
 use ignore::WalkBuilder;
-use std::{path::Path, time::SystemTime};
+use std::path::Path;
+use time::OffsetDateTime;
 
-pub(crate) fn dir_mtime(path: &Path) -> Option<SystemTime> {
+pub(crate) fn dir_mtime(path: &Path) -> Option<OffsetDateTime> {
     WalkBuilder::new(path)
         .standard_filters(true)
         .hidden(false)
@@ -10,5 +11,6 @@ pub(crate) fn dir_mtime(path: &Path) -> Option<SystemTime> {
         .filter_map(|entry| entry.metadata().ok())
         .filter(|metadata| metadata.is_file())
         .filter_map(|metadata| metadata.modified().ok())
+        .map(OffsetDateTime::from)
         .max()
 }
